# Script for spell checking

[![Check PEP8](https://travis-ci.org/kodSIM/spellchecker.svg?branch=master)](https://travis-ci.org/kodSIM/spellchecker)

For run script use format:

    python spellchecker.py [path to test case file or directory] [path to dictionary file]